part of katana_functions;

/// Message object used in [Functions.openAIChatGPT].
///
/// The [role] contains the role of the message, [text] the content of the message, and [token] the number of tokens generated by the message.
///
/// [Functions.openAIChatGPT]で利用するメッセージオブジェクト。
///
/// [role]にはメッセージの役割を、[text]にはメッセージの内容を、[token]にはメッセージで発生したトークンの数が入ります。
class OpenAIChatGPTMessage {
  const OpenAIChatGPTMessage({
    required this.role,
    required this.text,
    this.token,
  });

  /// Role of the message.
  ///
  /// メッセージの役割。
  final OpenAIChatGPTRole role;

  /// Message Content.
  ///
  /// メッセージの内容。
  final String text;

  /// Tokens generated through the use of ChatGPT.
  ///
  /// ChatGPTの利用で発生したトークン。
  ///
  /// See also:
  ///   * https://openai.com/pricing
  final int? token;
}

/// Role of OpenAI messages.
///
/// OpenAIのメッセージの役割。
enum OpenAIChatGPTRole {
  /// User.
  ///
  /// ユーザー。
  user,

  /// Assistant.ChatGPT.
  ///
  /// アシスタント。ChatGPT。
  assistant,
}

/// Available models of ChatGPT.
///
/// ChatGPTの利用可能モデル。
enum OpenAIChatGPTModel {
  gpt35Turbo;

  /// Returns the actual name passed to Functions.
  ///
  /// Functionsに渡される実際の名前を返します。
  String get name {
    switch (this) {
      case OpenAIChatGPTModel.gpt35Turbo:
        return "gpt-3.5-turbo";
    }
  }
}
